'use strict'

class PromiseTimeOutError extends Error {
  constructor (time) {
    super()
    this.name = 'PromiseTimeOutError'
    this.message = `Promise timed out after ${time} ms.`
  }
}

module.exports = (promise, time) => {
  return new Promise((resolve, reject) => {
    let timeout = setTimeout(() => {
      reject(new PromiseTimeOutError(time))
    }, time)

    promise
      .then(res => {
        clearTimeout(timeout)
        resolve(res)
      })
      .catch(err => {
        clearTimeout(timeout)
        reject(err)
      })
  })
}

module.exports.PromiseTimeOutError = PromiseTimeOutError
