'use strict'

/* global describe, it */

const assert = require('assert')

const promiseTimeout = require('./')

const pause = (delay, value, rejection) => {
  return new Promise((resolve, reject) => {
    setTimeout(() => rejection ? reject(value) : resolve(value), delay)
  })
}

describe('timeouts', () => {
  it('should resolve', (done) => {
    const value = 'hello world'
    const timeout = 2000

    promiseTimeout(pause(10, value), timeout)
      .then(output => {
        assert(output === value)
      })
      .then(done)
      .catch(_ => {
        assert(false)
        done()
      })
  })

  it('should resolve', (done) => {
    const value = 'hello world 2'
    const timeout = 2000

    promiseTimeout(pause(1500, value), timeout)
      .then(output => {
        assert(output === value)
      })
      .then(done)
      .catch(_ => {
        assert(false)
        done()
      })
  })

  it('should reject with time out error', (done) => {
    const value = 'hello world 2'
    const timeout = 200

    promiseTimeout(pause(1500, value), timeout)
      .catch(err => {
        assert(err instanceof promiseTimeout.PromiseTimeOutError)
        done()
      })
  })

  it('should reject with promise rejection', (done) => {
    const value = 'hello world 3'
    const timeout = 2000

    promiseTimeout(pause(1500, value, true), timeout)
      .catch(err => {
        assert(!(err instanceof promiseTimeout.PromiseTimeOutError))
        assert(err === value)
        done()
      })
  })
})
